BBBBBBB BBBBBBBBBBBBBBBBBBBBBBBBBBB
BBBB BBBBBBBBBBBBBBBBB BBBB BBBBBBBBBBBBBBBBBBBB BBBBBB


BBBBB BBBBBBB

BB BBBB
    XXXXXXXXXXXXXXXX
    XXXXXX
        BBBBBB BBBB BBBBBBBBBBBBBBBBBBBBBB
        XXXXXX XXXXXXXXXXXXX XXXXXXXXXXXXXX XXXXXXXXXX XXXXXXXXXXX XXXXXX XXXXXXXXX XXXXXXXXXXXXXXX
    XXXXXXX
BBBBB
    XXX XXXXXXXXXXXXXXXXXXXXXXXXX
    XXXX XXXXXXXXXXXX XXXXXX
        XXXX XXXXXXXXXXXXXXXXXX
            XXXX XXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXX
                XXXX XXXXXXXXXXXXXXX XXXXXXXXXXXXX
                    XXX XXXXXXXXXXXXXXXXX XXXXXXXXXXXXX

                        BBB BBBBB BB BBBBBBBBBBBBBBBBBBBBBBBBBB
                            XXX XXXXXXXXXXXXXXXXXXXXXXXXX
                                XX XXXXXXXX XXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXX
                                    BB BBBBBBBBBB BB BBBBB
                                        XX XXXXXXXXX XXXXXXXXXXXXXXXXXX
                                    BBBB BBBBBBBBBB BB BBBBBB
                                        XX XXXXXXXXX XXXXXXXXXXXXXXXXXXX
                                    BBBB
                                        XX XXXXXXXXX XXXXXXXXXXXXXXXXXX
                                    BBBBB 
                                XXXXXXXXX
                        BBBBBB
                    XXXXX
                XXXXXX
                XXXX XXXXXXXXXXXXXXXXXX XXXXXXXXXXX XXXXXXXXXXXXXXXX
                BB BBBBBBBBBBBBBBBBBBBBBBBBBB
                    
                    BB BBBBBBBBBBBBBBBBBBBBBBBBB BB BBBBBBBBBB
                        XXXXXXX XXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXX
                    BBBB BBBBBBBBBBBBBBBBBBBBBBBBB BB BBBBBBBBBBBB
                        
                    BBBBB


                BBBBB
            XXXXXX
            XXXX XXXXXXXXXXXXXXXXXXXXX
                BBBBBBB BBBBBBBBBBBBBBBBBBBBBBBBBBBB BBBB BBBBBBBBBBBBBBBBB
            XXXXXX
        XXXXXX
    XXXXXX


BBBBBBBB
BBBBB BBBBBBBBB
    XXXXXXX XXXXXBBBBBB BBBBBBBBBBBBBBBBBBBBBBBBBXXXXXXXXXXX
    XXXXXXX XXXXXBBBBBB BBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBXXXXXXXXXXX
    XXXXXXX XXXXXBBBBBB BBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBBXXXXXXXXXXX


    XXXXXXXX
        XXXXXXXXXXXXXXXXXXXXXXXXXX XX X
            XXX XXXX X FFFFFFFX

            XXX XXXXXXXXXXXXXX X XXXXXXXXXXXXXXXXX

            XXXXXXXX XXXXXXXXXXXXXXX X
                XXXXXXXX XXXXXXXXXXXXXXXXXX X
                    XXX XXXXXXXXXXX X XXX XXXXXXX
                    XXX XXXXXXXXX X XXX XXXXXXX
                    XXX XXXXXXXXX X XXXXXXXXXXXX
                    XXX XXXXXXXXXX X XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
                    XXX XXXXXXXX X XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
                    XX XXXXXXXXXXXXXXXXX XX XXXXXXXXXXXXXXX X
                        XXXXXXXXXXX X XXX XXXXXXXXXXXXXXXXXXXXXXX
                        XXXXXXXXX X XXX XXXXXXXXXXXXXXXXXXXXX
                    X XXXX X
                        XXXXXXXXXXXXXXXXXXXXXXXX
                        XXXXXXXXXXXXXXXXXXXXXXXXXX
                        XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X XXX
                        XXXXXXXXXXXXXXXXXXXXXX
                        XXXXXXXXXXXXXXXXXXXXXXXX
                    X

                    XXXXXX X

                        XXXXXXXXXXXXXXXX XXXXXX
                        XXXXXXXXXXX XXXXX
                        XXXXXXXXXXXXXXXXX XXXXX
                        XXXXXXXXXXXXXXXXXXXX XXX
                        XXXXXXXXXX XXXXX
                        XXXXXXXXXX XXXXXXXXXXXX
                        XXXXXXXX XXXXXXXXXX
                        XXXXXXXXXXXXXXXXXXXX XXXXX

                        XXXXXXX X
                            X gettext(u'Today') XX XXXXXXXXXXXXX XXXXXXXXXXX
                            X gettext(u'Yesterday') XX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXX
                            X gettext(u'Last 7 Days') XX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXX XXXXXXXXXXXXXXXXXXX
                            X gettext(u'This Month') XX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
                            X gettext(u'Last Month') XX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXX
                        XX

                        XXXXXX XXXXXXXX
                        XXXXXXXXXXXXXX XXXXX
                        XXXXXXXXXXXXXXXX XXXXXX
                        XXXXXXXXXXXXXX XXXXXXXX
                        XXXXXXXXXXX XXXXXXXXXX XXXXXXXX XXXXXXXXXXX
                        XXXXXXXXXXXX XXXXXXXXXX XXXXXXXXXXX XXXXXXXXXXX
                        XXXXXXX X
                            XXXXXXXXXX BB BBBBBBBBBBBBB XXXXX BBBBXXXXXBBBBBX
                            XXXXXXX XXXXXXXXXXXXX
                            XXXXXXXXXXX X gettext(u'Apply') XX
                            XXXXXXXXXX X gettext(u'From') XX
                            XXXXXXXX X gettext(u'To') XX
                            XXXXXXXXXXX X gettext(u'start date') XXX
                            XXXXXXXXX X gettext(u'end date') XXX
                            XXXXXXXXXXXX X gettext(u'Cancel') XX
                            XXXXXXXXXXXXXXXXX X gettext(u'choose') XX
                            XXXXXXXXX X
                        X
                    XX
                X

                XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXX XXXX XXXXXXX X
                    XXX XXXXXXXXX X XXXXXXXXXXXXXXX
                    XXX XXXXXXXXXX X XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
                    XXX XXXXXXXX X XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
                    XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X XXX X XXXXXXXXXXXXXXXXXXXXXXXXXXXXX X XXX X XXXXXXXXXXXXXXXXXXXXXXXXXXXXX X X X X XXXXXXXXXXXXXXXXXXXXXXXXXXXXX X XXX X XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
                    XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX X XXX X XXXXXXXXXXXXXXXXXXXXXXXXXXX X XXX X XXXXXXXXXXXXXXXXXXXXXXXXXXX X X X X XXXXXXXXXXXXXXXXXXXXXXXXXXX X XXX X XXXXXXXXXXXXXXXXXXXXXXXXXXXX
                    XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
                XX

            X

            XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXX XXX XXXXXXXX XXX X
                XXXXXXXXXXXXXXXXXXX
                XXX XXXXX X XXXXXXXX
                XXX XXXXXXXXXXXXX X XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX

                XX XXXXXXXXXXXXXX XXX XXXXXXXXXXX X
                    XXXXXXXXXXXXXXXXXXXXXXXXXXX
                X XXXX XX XXXXXXXXXXXXXX XXX XXXXXXXXXXXXX X
                    XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
                X

                XXX XX X XXXXXXXXXXXXXXXXXXXX
                XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXX XXX XXXXXX XXXXXXX
                XXXXXXXXXXXXXXXXXXXXXXXXXXX X XXXXXXXXXXXXXXXXXXXXXXXXXXX X XXXXXXXXXXXXXXXXXXXXXXXX XX XXX XXX XXX XXXXXX XXXXX


            XXX

            XXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXX X
                XXXXXXXXXXXXXXXXXXXXXXX
                XXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXX

                XXX XXXXX X XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
                XXX XXXXXXXXXXX X XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXXX
                XXXXXXXXXXXXXXXXXXXXXXXXXXXXX

            X

            XXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXX X
                XXXXXXXXXXXXXXXXXXXXXXX
                XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX  XXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXX
                XXX XXXXXX X XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
                XXX XXXXXXXXXXX X XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXXXXXXXXXXXXXXXXXXXXXXXXXX XXXX
                XXXXXXX X XXX XXXXXXXXXXXXX XXXXXXXXXXXXX

            X

            XXXXXXXXXXXXXXXXXXXXXXX
            XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
            XXXXXXXXXXXXXXXX


        XX
    XXXXXXXXX

BBBBBBBB
